using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using Vevo.Base.Data.Caching;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Marketing;
using Vevo.Shared.Utilities;

namespace Vevo.Data
{
    public class GiftRegistryRepository : IGiftRegistryRepository
    {
        #region Private

        private const string RepositoryName = "GiftRegistryRepository";

        private const string GetOneSignature = "GetOne";
        private const string GetAllByUserNameSignature = "GetAllByUserName";
        private const string SearchSignature = "Search";
        private const string TableName = "GiftRegistry";
        private DataCache _dataCache = new DataCache( RepositoryName );
        private ICacheDependencyUtility _cacheDependency = new CacheDependencyUtility( TableName );

        private GiftRegistryRepositoryNoCache _repository = new GiftRegistryRepositoryNoCache();

        #endregion

        #region Constructors

        public GiftRegistryRepository()
        {
        }

        public GiftRegistryRepository( ICacheDependencyUtility cacheDependency )
        {
            _cacheDependency = cacheDependency;
        }

        #endregion

        #region Public Methods

        public GiftRegistry Save( GiftRegistry giftRegistry )
        {
            // Need to write to database first before clearing cache.
            // Otherwise, cache may remember incorrect values before saving.
            GiftRegistry newGiftRegistry = _repository.Save( giftRegistry );
            _dataCache.ClearRepositoryCache();
            return newGiftRegistry;
        }

        public GiftRegistry GetOne( string giftRegistryID )
        {
            GiftRegistry result = (GiftRegistry) _dataCache.GetValue( GetOneSignature, _cacheDependency, giftRegistryID );

            if (result == null)
            {
                result = _repository.GetOne( giftRegistryID );
                _dataCache.SetValue( GetOneSignature, result, giftRegistryID );
            }

            return result;
        }

        public void Delete( string giftRegistryID )
        {
            _repository.Delete( giftRegistryID );
            _dataCache.ClearRepositoryCache();
        }

        public IList<GiftRegistry> GetAllByUserName( string userName, string storeID )
        {
            IList<GiftRegistry> list = (IList<GiftRegistry>) _dataCache.GetValue(
                    GetAllByUserNameSignature,
                    _cacheDependency,
                    userName,
                    storeID
                    );

            if (list == null)
            {
                list = _repository.GetAllByUserName( userName, storeID );
                _dataCache.SetValue(
                    GetAllByUserNameSignature,
                    list,
                    userName,
                    storeID
                    );
            }

            return list;
        }

        public IList<GiftRegistry> Search(
            string firstName,
            string lastName,
            string eventName,
            string startEventDate,
            string endEventDate,
            string storeID,
            int startIndex,
            int endIndex,
            out int howManyItems )
        {
            howManyItems = 0;
            Pair result = (Pair) _dataCache.GetValue(
                SearchSignature,
                _cacheDependency,
                firstName,
                lastName,
                eventName,
                startEventDate,
                endEventDate,
                storeID,
                startIndex,
                endIndex
                );

            if (result == null)
            {
                result = new Pair();
                result.First = _repository.Search(
                    firstName, lastName, eventName, startEventDate, endEventDate, storeID, startIndex, endIndex, out howManyItems );
                result.Second = howManyItems;
                _dataCache.SetValue(
                    SearchSignature,
                    result,
                    firstName,
                    lastName,
                    eventName,
                    startEventDate,
                    endEventDate,
                    storeID,
                    startIndex,
                    endIndex );
            }

            howManyItems = ConvertUtilities.ToInt32( result.Second );
            return (IList<GiftRegistry>) result.First;
        }

        #endregion
    }
}
