using System;
using System.Globalization;

using Vevo.Shared.Utilities;

namespace Vevo.Domain
{
    public class Currency : ICloneable
    {
        #region Private

        private string _currencyCode = String.Empty;
        private string _currencySymbol = String.Empty;
        private string _name = String.Empty;
        private double _conversionRate = 1.0;
        private bool _enabled = true;
        private string _currencyposition = String.Empty;

        #endregion


        #region Public Properties

        public static Currency Null
        {
            get { return NullCurrency.Instance; }
        }

        public virtual bool IsNull
        {
            get { return false; }
        }

        public string CurrencyCode { get { return _currencyCode; } set { _currencyCode = value; } }
        public string CurrencySymbol { get { return _currencySymbol; } set { _currencySymbol = value; } }
        public string Name { get { return _name; } set { _name = value; } }
        public double ConversionRate { get { return _conversionRate; } set { _conversionRate = value; } }
        public bool Enabled { get { return _enabled; } set { _enabled = value; } }
        public string CurrencyPosition { get { return _currencyposition; } set { _currencyposition = value; } }

        #endregion


        #region Public Methods

        public static decimal RoundAmount( decimal amount )
        {
            return Math.Round( amount, SystemConst.DecimalPointLenght, MidpointRounding.AwayFromZero );
        }

        public static decimal RoundAmount( object amount )
        {
            return RoundAmount( ConvertUtilities.ToDecimal( amount ) );
        }

        public string FormatPrice( decimal basePrice )
        {
            if ( _currencyposition == "Before" )
                return String.Format(
                    "{0}{1:n2}",
                    CurrencySymbol,
                    basePrice * Convert.ToDecimal( ConversionRate ) );
            else
                return String.Format(
                "{1:n2}{0}",
                CurrencySymbol,
                basePrice * Convert.ToDecimal( ConversionRate ) );
        }

        public string FormatPriceInvert( decimal basePrice )
        {
            return String.Format(
                "{0}{1:n2}",
                CurrencySymbol,
                basePrice / Convert.ToDecimal( ConversionRate ) );
        }

        public string FormatPrice( object basePrice )
        {
            return FormatPrice( ConvertUtilities.ToDecimal( basePrice ) );
        }

        public string FormatPriceInvert( object basePrice )
        {
            return FormatPriceInvert( ConvertUtilities.ToDecimal( basePrice ) );
        }

        public string FormatPriceWithOutSymbol( decimal basePrice )
        {
            return String.Format(
                "{0:n2}", basePrice * Convert.ToDecimal( ConversionRate ) );
        }

        public string FormatPriceWithOutSymbolInvert( decimal basePrice )
        {
            return String.Format(
                "{0:n2}", basePrice / Convert.ToDecimal( ConversionRate ) );
        }

        // Format the price with two decimal places and using "." as a decimal separator.

        public static String ConvertPriceToUSFormat( object price )
        {
            CultureInfo usCultureInfo = new CultureInfo( SystemConst.USCultureName );
            return String.Format(
                usCultureInfo,
                "{0:f" + SystemConst.DecimalPointLenght + "}",
                ConvertUtilities.ToDecimal( price ) );
        }

        public static string ConvertPriceToSelectedCurrency( decimal basePrice, string selectedCurrencyCode )
        {
            Currency currency = DataAccessContext.CurrencyRepository.GetOne( selectedCurrencyCode );

            if ( currency.IsNull || currency == Currency.Null )
            {
                return "";
            }
            else
            {
                return String.Format( "{0:n2} ", basePrice * Convert.ToDecimal( currency.ConversionRate ) ) + currency.CurrencyCode;
            }
        }

        #endregion


        #region IClonable Members

        // Copy the whole aggregate (including locale)
        public object Clone()
        {
            Currency newObject = ( Currency ) MemberwiseClone();
            return newObject;
        }

        #endregion
    }

}
