﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Vevo.Domain.Base;
using Vevo.Domain.Contents;

namespace Vevo.Domain.EmailTemplates
{
    public class EmailTemplateDetail : ILocaleLoader, ICloneable
    {
        #region Private

        private string _emailTemplateDetailID = "0";
        private string _emailTemplateDetailName = String.Empty;
        private string _description = String.Empty;
        private string _storeID = "0";

        private Culture _defaultCulture;
        private LocaleCollection<EmailTemplateDetailLocale> _locales;
        
        #endregion

        #region Public Constructors

        public EmailTemplateDetail( Culture defaultCulture )
        {
            _defaultCulture = defaultCulture;
            _locales = new LocaleCollection<EmailTemplateDetailLocale>( this );
        }

        #endregion

        #region Public Properties

        public string EmailTemplateDetailID { get { return _emailTemplateDetailID; } set { _emailTemplateDetailID = value; } }
        public string EmailTemplateDetailName { get { return _emailTemplateDetailName; } set { _emailTemplateDetailName = value; } }
        public string Description { get { return _description; } set { _description = value; } }
        public string StoreID { get { return _storeID; } set { _storeID = value; } }

        public Culture DefaultCulture { get { return _defaultCulture; } set { _defaultCulture = value; } }
        public LocaleCollection<EmailTemplateDetailLocale> Locales { get { return _locales; } }

        public string Subject
        {
            get { return Locales[DefaultCulture].Subject; }
            set { Locales.GetNoLoad( DefaultCulture ).Subject = value; }
        }

        public string Body
        {
            get { return Locales[DefaultCulture].Body; }
            set { Locales.GetNoLoad( DefaultCulture ).Body = value; }
        }
        
        public static EmailTemplateDetail Null
        {
            get { return NullEmailTemplateDetail.Instance; }
        }

        public virtual bool IsNull
        {
            get { return false; }
        }

        #endregion

        #region ILocaleLoader Members

        public IList<ILocale> GetLocales()
        {
            List<ILocale> result = new List<ILocale>();

            foreach (EmailTemplateDetailLocale locale in
                DataAccessContext.EmailTemplateDetailRepository.GetLocales( EmailTemplateDetailID ))
            {
                result.Add( locale );
            }

            return result;
        }

        #endregion

        #region IClonable Members

        // Copy the whole aggregate (including locale)
        public object Clone()
        {
            EmailTemplateDetail newObject = (EmailTemplateDetail) MemberwiseClone();
            newObject._locales = (LocaleCollection<EmailTemplateDetailLocale>) Locales.Clone();
            return newObject;
        }

        #endregion
    }
}
