﻿using System;
using System.Collections.Generic;
using Vevo.Domain.Base;

namespace Vevo.Domain.Marketing
{
    public class Banner : ILocaleLoader
    {
        #region Private

        private string _bannerID = "0";
        private string _storeID = "1";
        private string _name = String.Empty;
        private DateTime _createDate = DateTime.Now;
        private DateTime _EndDate = DateTime.MaxValue;
        private bool _isEnabled = true;
        private int _sortOrder = 0;

        private Culture _defaultCulture;
        private LocaleCollection<BannerLocale> _locales;

        #endregion

        #region Public Properties

        public string BannerID { get { return _bannerID; } set { _bannerID = value; } }
        public string StoreID { get { return _storeID; } set { _storeID = value; } }
        public string Name { get { return _name; } set { _name = value; } }
        public DateTime CreateDate { get { return _createDate; } set { _createDate = value; } }
        public DateTime EndDate { get { return _EndDate; } set { _EndDate = value; } }
        public bool IsEnabled { get { return _isEnabled; } set { _isEnabled = value; } }
        public int SortOrder { get { return _sortOrder; } set { _sortOrder = value; } }

        public Culture DefaultCulture { get { return _defaultCulture; } set { _defaultCulture = value; } }
        public LocaleCollection<BannerLocale> Locales { get { return _locales; } }

        public static Banner Null
        {
            get { return NullBanner.Instance; }
        }

        public virtual bool IsNull
        {
            get { return false; }
        }

        #endregion

        #region Custom Properties

        //------------------------------------------------------------
        // Locale items
        public string ImageURL
        {
            get { return Locales[ DefaultCulture ].ImageURL; }
            set { Locales.GetNoLoad( DefaultCulture ).ImageURL = value; }
        }

        public string LinkURL
        {
            get { return Locales[ DefaultCulture ].LinkURL; }
            set { Locales.GetNoLoad( DefaultCulture ).LinkURL = value; }
        }

        public string Description
        {
            get { return Locales[ DefaultCulture ].Description; }
            set { Locales.GetNoLoad( DefaultCulture ).Description = value; }
        }
        // End Locale items
        //------------------------------------------------------------

        #endregion

        #region Public Constructors

        public Banner()
        {
            _defaultCulture = new Culture();
            _locales = new LocaleCollection<BannerLocale>( this );
        }

        public Banner( Culture defaultCulture )
        {
            _defaultCulture = defaultCulture;
            _locales = new LocaleCollection<BannerLocale>( this );
        }

        #endregion

        #region ILocaleLoader Members

        public IList<ILocale> GetLocales()
        {
            return DataAccessContext.BannerRepository.GetLocales( BannerID );
        }

        #endregion

        #region IClonable Members

        // Copy the whole aggregate (including locale)
        public object Clone()
        {
            Banner newObject = ( Banner ) MemberwiseClone();
            newObject._locales = ( LocaleCollection<BannerLocale> ) Locales.Clone();

            return newObject;
        }

        #endregion
    }
}
