using System;
using System.Collections.Generic;
using System.Text;

namespace Vevo.Domain.Orders
{
    public class OrderAmount
    {
        #region Factory Class

        public class Factory
        {
            private decimal _subtotal;
            private decimal _discount;
            private decimal _pointDiscount;
            private decimal _shippingCost;
            private decimal _handlingFee;
            private decimal _tax;
            private decimal _giftCertificate;

            public Factory WithSubtotal( decimal value ) { _subtotal = value; return this; }
            public Factory WithDiscount( decimal value ) { _discount = value; return this; }
            public Factory WithPointDiscount( decimal value ) { _pointDiscount = value; return this; }
            public Factory WithShippingCost( decimal value ) { _shippingCost = value; return this; }
            public Factory WithHandlingFee( decimal value ) { _handlingFee = value; return this; }
            public Factory WithTax( decimal value ) { _tax = value; return this; }
            public Factory WithGiftCertificate( decimal value ) { _giftCertificate = value; return this; }

            public OrderAmount Create()
            {
                return new OrderAmount( _subtotal, _discount, _pointDiscount, _shippingCost, _handlingFee,
                    _tax, _giftCertificate );
            }
        }

        public static Factory GetFactory() { return new Factory(); }

        #endregion


        #region Private

        private decimal _subtotal;
        private decimal _discount;
        private decimal _pointDiscount;
        private decimal _shippingCost;
        private decimal _handlingFee;
        private decimal _tax;
        private decimal _giftCertificate;

        #endregion


        #region Constructors

        public OrderAmount()
        {
        }

        public OrderAmount(
            decimal subtotal,
            decimal discount,
            decimal pointDiscount,
            decimal shippingCost,
            decimal handlingFee,
            decimal tax,
            decimal giftCertificate )
        {
            _subtotal = subtotal;
            _discount = discount;
            _pointDiscount = pointDiscount;
            _shippingCost = shippingCost;
            _handlingFee = handlingFee;
            _tax = tax;
            _giftCertificate = giftCertificate;
        }

        #endregion


        #region Public Properties

        public decimal Subtotal { get { return _subtotal; } }
        public decimal Discount { get { return _discount; } }
        public decimal PointDiscount { get { return _pointDiscount; } }
        public decimal ShippingCost { get { return _shippingCost; } }
        public decimal HandlingFee { get { return _handlingFee; } }
        public decimal Tax { get { return _tax; } }
        public decimal GiftCertificate { get { return _giftCertificate; } }

        public decimal Total
        {
            get
            {
                decimal total = _subtotal - _discount - _pointDiscount + _shippingCost + _handlingFee + _tax - _giftCertificate;
                if (total < 0)
                    total = 0;

                return total;
            }
        }

        #endregion


        #region Public Methods

        public OrderAmount Add( OrderAmount rhs )
        {
            return OrderAmount.GetFactory()
                .WithSubtotal( Subtotal + rhs.Subtotal )
                .WithDiscount( Discount + rhs.Discount )
                .WithPointDiscount( PointDiscount + rhs.PointDiscount )
                .WithShippingCost( ShippingCost + rhs.ShippingCost )
                .WithHandlingFee( HandlingFee + rhs.HandlingFee )
                .WithTax( Tax + rhs.Tax )
                .WithGiftCertificate( GiftCertificate + rhs.GiftCertificate )
                .Create();
        }

        #endregion
    }
}
