using System;
using System.Collections.Generic;
using System.Text;

using Vevo.Domain.Configurations;
using Vevo.Domain.Orders;

namespace Vevo.Domain.Payments
{
    public abstract class AnonymousPaymentMethod : PaymentMethod
    {
        public AnonymousPaymentMethod( ConfigurationCollection configurations )
            : base( configurations )
        {
        }

        public override bool CreditCardRequired
        {
            get
            {
                return false;
            }
        }

        public override bool Cvv2Required
        {
            get
            {
                return false;
            }
        }

        public override bool BillingAddressRequired
        {
            get
            {
                return false;
            }
        }

        public override bool AnonymousCheckoutAllowed
        {
            get { return true; }
        }

        public override bool PaymentMethodSelectionAllowed
        {
            get { return false; }
        }

        public abstract bool ProcessPayment(
            decimal amount,
            string currency,
            CheckoutDetails checkout,
            out ProcessPaymentResult result );

        public override string[] SupportedCreditCards
        {
            get { return new string[] { "Visa Credit", "MasterCard Credit", "Discover", "American Express" }; }
        }

        public override string[] SupportedCreditCardValues
        {
            get { return new string[] { "Visa", "MasterCard", "Discover", "Amex" }; }
        }

        public override bool IsCreditCardNumberSaved
        {
            get { return false; }
        }

        public override bool CanUseRecurring
        {
            get { return false; }
        }
    }
}
