﻿using System;
using System.Collections.Generic;
using System.Text;
using Vevo.Domain;
using Vevo.Domain.Base;
using Vevo.Domain.Stores;
using Vevo.Shared.DataAccess;
using Vevo.Domain.Configurations;

namespace Vevo.Domain.Products
{
    public class Department : BaseCategory, IBaseCategory
    {
        #region Private

        private string _departmentID = "0";
        private string _parentDepartmentID = "0";
        private string _departmentListLayoutPath = String.Empty;

        private bool GetDepartmentInList(
            Culture culture,
            IList<Department> departmentList,
            string departmentID,
            out Department department )
        {
            foreach (Department departmentItem in (IList<Department>) departmentList)
            {
                if (departmentItem.DepartmentID == departmentID)
                {
                    department = departmentItem;
                    return true;
                }
            }
            department = new Department( culture );
            return false;
        }

        private bool IsParentDepartmentVisible( IBaseCategory inDepartment, string rootID, Culture culture )
        {
            Department department = (Department) inDepartment;
            if (department.RootID == rootID)
            {
                if (department.IsEnabled)
                {
                    if (department.ParentDepartmentID != rootID)
                    {
                        CategoryRepositoryHelper categoryRepositoryHelper = new CategoryRepositoryHelper( this.GetType() );
                        Department parentCategory = (Department) categoryRepositoryHelper.GetOne( culture, department.ParentDepartmentID );
                        if (IsParentDepartmentVisible( parentCategory, rootID, culture ))
                            return true;
                    }
                    else
                    {
                        return true;
                    }
                }
            }

            return false;
        }

        private string CreateFullDepartmentPathWithEndText( string endText )
        {
            string result = endText;
            string root = RootID;
            string parent = ParentDepartmentID;
            while ((parent != root) && (parent != "0"))
            {
                Department department = DataAccessContext.DepartmentRepository.GetOne( DefaultCulture, parent );
                if (department != null)
                {
                    result = department.Name + " >> " + result;
                    parent = department.ParentDepartmentID;
                }
            }
            return result;
        }

        #endregion

        #region Public Constructors

        public Department( Culture defaultCulture )
            : base( defaultCulture )
        {

        }

        public Department()
            : base()
        {

        }

        #endregion

        #region Public Properties

        public static Department Null
        {
            get { return NullDepartment.Instance; }
        }

        public string DepartmentID { get { return _departmentID; } set { _departmentID = value; } }
        public string ParentDepartmentID { get { return _parentDepartmentID; } set { _parentDepartmentID = value; } }
        public string DepartmentListLayoutPath { get { return _departmentListLayoutPath; } set { _departmentListLayoutPath = value; } }

        #endregion

        #region IClonable Members

        public override object Clone()
        {
            Department newObject = (Department) MemberwiseClone();
            newObject._locales = (LocaleCollection<BaseCategoryLocale>) Locales.Clone();

            return newObject;
        }

        #endregion

        #region ILocaleLoader Members

        public override IList<ILocale> GetLocales()
        {
            List<ILocale> result = new List<ILocale>();
            foreach (DepartmentLocale locale in DataAccessContext.DepartmentRepository.GetLocales( DepartmentID ))
                result.Add( locale );

            return result;
        }

        #endregion

        #region Public Methods

        public override bool IsParentsEnable()
        {
            if (IsParentDepartmentVisible( this, RootID, DefaultCulture ))
                return true;
            else
                return false;
        }

        public bool IsLeafDepartment( IList<Department> allDepartments )
        {
            foreach (Department department in allDepartments)
            {
                if (department.ParentDepartmentID == DepartmentID)
                    return false;
            }
            return true;
        }

        public bool IsLeafDepartment()
        {
            return DataAccessContext.DepartmentRepository.IsLeaf( DepartmentID );
        }

        public string CreateFullDepartmentPath()
        {
            return CreateFullDepartmentPathWithEndText( Name );
        }

        public string CreateFullDepartmentPathParentOnly()
        {
            return CreateFullDepartmentPathWithEndText( "" );
        }

        public string CreateParentDepartmentPathList()
        {
            string result = String.Empty;
            string root = RootID;
            string parent = ParentDepartmentID;

            while ((parent != root) && (parent != "0"))
            {
                Department department = DataAccessContext.DepartmentRepository.GetOne( DefaultCulture, parent );
                if (department != null)
                {
                    result = result + department.Name + " - ";
                    parent = department.ParentDepartmentID;
                }
            }
            return result;

        }

        public override IList<IBaseCategory> GetBreadcrumb()
        {
            IList<IBaseCategory> breadcrumb = new List<IBaseCategory>();

            breadcrumb.Insert( 0, this );

            string id = ParentDepartmentID;
            while (id != "0")
            {
                IBaseCategory category = DataAccessContext.DepartmentRepository.GetOne( DefaultCulture, id );

                breadcrumb.Insert( 0, category );
                Department department = (Department) category;
                id = department.ParentDepartmentID;
            }

            return breadcrumb;
        }

        public string GetMetaDescription( Culture culture )
        {
            string metaDescription = SeoVariable.ReplaceDepartmentVariable(
                       DataAccessContext.DepartmentRepository.GetOne( culture, DepartmentID ),
                       culture,
                       DataAccessContext.Configurations.GetValue(
                           culture.CultureID,
                           "DefaultDepartmentMetaDescription",
                           DataAccessContext.StoreRepository.GetOne( DataAccessContext.StoreRetriever.GetCurrentStoreID() ) ) );

            return GetMetaDescription( culture, metaDescription );
        }

        public string GetMetaKeyword( Culture culture )
        {
            string metaKeyword = SeoVariable.ReplaceDepartmentVariable(
                  DataAccessContext.DepartmentRepository.GetOne( culture, DepartmentID ),
                  culture,
                  DataAccessContext.Configurations.GetValue(
                      culture.CultureID,
                      "DefaultDepartmentMetaKeyword",
                      DataAccessContext.StoreRepository.GetOne( DataAccessContext.StoreRetriever.GetCurrentStoreID() ) ) );

            return GetMetaKeyword( culture, metaKeyword );
        }
        #endregion
    }
}
