﻿using System;
using System.Collections.Generic;
using System.Text;
using Vevo.Domain.Base;

namespace Vevo.Domain.Products
{
    public class ProductKitItemDisplay
    {
        private ProductKitItem _productKitItem;
        private Culture _culture;
        private string _storeID;
        private bool _isDynamicPrice;

        public ProductKitItemDisplay( ProductKitItem item, Culture culture, string storeID,bool isDynamicPrice )
        {
            _productKitItem = item;
            _culture = culture;
            _storeID = storeID;
            _isDynamicPrice = isDynamicPrice;
        }

        public string ProductID { get { return _productKitItem.ProductID; } }
        public string DisplayName
        {
            get
            {
                Product product = DataAccessContext.ProductRepository.GetOne( _culture, ProductID, _storeID );
                if (!_isDynamicPrice)
                    return product.Name;
                else
                    return product.Name + " (+" + Currency.RoundAmount( product.GetProductPrice( _storeID ).Price ) + ")";
            }
        }
        public bool IsUserDefinedQuantity { get { return _productKitItem.IsUserDefinedQuantity; } }
        public string Quantity { get { return _productKitItem.Quantity.ToString(); } }
        public bool IsDefault { get { return _productKitItem.IsDefault; } }
    }

    public class ProductKitItem : ICloneable
    {
        #region Private

        private string _productKitGroupID = "0";
        private string _productID = "0";
        private int _quantity = 1;
        private bool _isUserDefinedQuantity = false;
        private int _sortOrder = 0;
        private bool _isDefault = false;

        #endregion


        #region Public Constructors

        public ProductKitItem()
        {
        }

        #endregion


        #region Public Properties

        public static ProductKitItem Null
        {
            get { return NullProductKitItem.Instance; }
        }

        public virtual bool IsNull
        {
            get { return false; }
        }

        public string ProductKitGroupID { get { return _productKitGroupID; } set { _productKitGroupID = value; } }
        public string ProductID { get { return _productID; } set { _productID = value; } }
        public int Quantity { get { return _quantity; } set { _quantity = value; } }
        public bool IsUserDefinedQuantity { get { return _isUserDefinedQuantity; } set { _isUserDefinedQuantity = value; } }
        public int SortOrder { get { return _sortOrder; } set { _sortOrder = value; } }
        public bool IsDefault { get { return _isDefault; } set { _isDefault = value; } }

        #endregion

        #region IClonable Members

        // Copy the whole aggregate (including locale)
        public object Clone()
        {
            ProductKitItem newObject = (ProductKitItem) MemberwiseClone();
            return newObject;
        }

        #endregion


        #region Public Methods

        //public decimal GetOptionPrice( decimal productPrice )
        //{
        //    if (OptionItemType == PriceType.Price)
        //        return PriceToAdd;
        //    else
        //        return (decimal) (PercentageChange / 100) * productPrice;
        //}

        #endregion
    }
}
