using System;
using System.Collections.Generic;
using System.Text;
using Vevo.Shared.WebUI;

using Vevo.Domain.Orders;
using System.Web;

namespace Vevo.Domain.Stores
{
    public class StoreRetriever : IStoreRetriever
    {
        #region Private
        private string _storeID = null;

        private string GetStoreIDFromURL()
        {
            if (!KeyUtilities.IsMultistoreLicense())
                return Store.RegularStoreID;

            else
            {
                try
                {
                    return DataAccessContext.StoreRepository.GetStoreIDByUrlName(
                        UrlPath.GetStoreFrontUrlWithoutWWWandHTTP() );
                }
                catch (Exception)
                {
                    //SaveLogFile.SaveLog( ex );
                    return Store.Null.StoreID;
                }
            }
        }

        private string FormatURL( string url )
        {
            string uriString = "http://" + url;
            Uri uri = new Uri( uriString );
            return uri.AbsoluteUri;
        }

        private bool IsGatewayFolder()
        {
            UrlPath path = new UrlPath( HttpContext.Current.Request.Url.AbsoluteUri );

            if (path.ExtractFirstApplicationSubfolder().ToLower() == "gateway")
                return true;
            else
                return false;
        }

        private bool IsMobileFolder()
        {
            foreach (string segments in HttpContext.Current.Request.Url.Segments)
            {
                if (segments.Substring( 0, segments.Length - 1 ).ToLower().Equals( "mobile" ))
                    return true;
            }

            return false;
        }

        private bool IsFacebookFolder()
        {
            foreach (string segments in HttpContext.Current.Request.Url.Segments)
            {
                if (segments.Substring( 0, segments.Length - 1 ).ToLower().Equals( "facebook" ))
                    return true;
            }

            return false;
        }

        private bool IsBlogFolder()
        {
            foreach (string segments in HttpContext.Current.Request.Url.Segments)
            {
                if (segments.Substring( 0, segments.Length - 1 ).ToLower().Equals( "blog" ))
                    return true;
            }
            return false;
        }
        #endregion

        #region Constructure

        public StoreRetriever()
        {
            _storeID = GetStoreIDFromURL();
        }

        public StoreRetriever( string storeID )
        {
            _storeID = storeID;
        }

        #endregion

        #region IStoreRetriever Members

        public string GetCurrentStoreID()
        {
            if (_storeID == null || _storeID == "0")
            {
                _storeID = GetStoreIDFromURL();
            }

            return _storeID;
        }

        public Store GetStore()
        {
            try
            {
                return DataAccessContext.StoreRepository.GetOne( GetStoreIDFromURL() );
            }
            catch (Exception ex)
            {
                SaveLogFile.SaveLog( ex );
                return Store.Null;
            }
        }

        public string GetStorefrontUrlByStoreID( string storeID )
        {
            return FormatURL( DataAccessContext.StoreRepository.GetOne( storeID ).UrlName );
        }

        public string GetStorefrontUrlByOrderID( string orderID )
        {
            Order order = DataAccessContext.OrderRepository.GetOne( orderID );
            return GetStorefrontUrlByStoreID( order.StoreID );
        }

        public bool IsStorefrontUrl()
        {
            UrlPath path = new UrlPath( HttpContext.Current.Request.Url.AbsoluteUri );

            if (path.IsStorefrontUrl() || IsGatewayFolder() || IsMobileFolder() || IsFacebookFolder() || IsBlogFolder())
                return true;
            else
                return false;
        }

        #endregion
    }
}
