using System;
using System.Collections.Generic;
using Vevo.Domain;
using Vevo.Domain.Orders;
using Vevo.Domain.Users;
using Vevo.QuickBooks.Qbxml70;

namespace Vevo.QuickBooks.States
{
    /// <summary>
    /// Summary description for CustomerVerifyResponseState
    /// </summary>
    public class CustomerVerifyResponseState : QBWCState
    {
        private void MoveToNextState()
        {
            QBWCSession.CurrentState = new CustomerQueryRequestState( QBWCSession );
        }

        private IList<Customer> GetAllData( string existList )
        {
            IList<Customer> table = DataAccessContext.CustomerRepository.GetByIsQBExported( true, existList );
            string qBAnonymousListID = DataAccessContext.Configurations.GetValue( "QBAnonymousListID" ).Trim();

            string storeID = getStoreID();
            IList<Order> orderList = DataAccessContext.OrderRepository.GetByIsQBExported( false, storeID, String.Empty );
            bool isAnonymous = false;
            foreach (Order order in orderList)
            {
                if (order.CustomerID.Equals( "0" ))
                {
                    isAnonymous = true;
                }
            }

            if (!String.IsNullOrEmpty( qBAnonymousListID ) && isAnonymous)
            {
                Customer customer = new Customer();
                customer.CustomerID = "0";
                customer.QBListID = qBAnonymousListID;
                customer.UseBillingAsShipping = true;
                customer.IsWholesale = false;

                table.Add( customer );
            }
            return table;
        }

        private string getStoreID()
        {
            return DataAccessContext.Configurations.GetValue( "QBSelectStoreExport" );
        }

        private void UpdateData( string existList )
        {
            IList<Customer> table = GetAllData( existList );

            foreach (Customer customer in table)
            {
                if (customer.CustomerID.Equals( "0" ))
                {
                    DataAccessContext.ConfigurationRepository.UpdateValue(
                        DataAccessContext.Configurations["QBAnonymousListID"], String.Empty );
                }
                else
                {
                    DataAccessContext.CustomerRepository.SetDefaultQBData( customer.QBListID );
                }
            }
        }

        private void ProcessResponse( string response )
        {
            QBXMLMsgsRs qbXmlMsgsRs = CreateResponse( response );
            string existList = String.Empty;
            for (int i = 0; i < qbXmlMsgsRs.Items.Length; i++)
            {
                CustomerQueryRsType result = (CustomerQueryRsType) qbXmlMsgsRs.Items[i];

                if (result.statusCode.ToString() == "0")
                {
                    if (String.IsNullOrEmpty( existList ))
                        existList = "'" + result.CustomerRet[0].ListID + "'";
                    else
                        existList += ",'" + result.CustomerRet[0].ListID + "'";
                }
            }
            UpdateData( existList );
        }

        public CustomerVerifyResponseState( QBWCSession session )
            : base( session )
        {
        }

        public override int OnReceiveResponseXml( string responseXml )
        {
            ProcessResponse( responseXml );

            MoveToNextState();

            return 8;
        }
    }
}