using System;
using System.Collections;
using System.Data;
using System.IO;
using System.Text;
using System.Web;

namespace Vevo.Reports.Exporters
{
    public class BestSellerReportExporter
    {
        private string _baseCurrencySymbol;
        private string _cultureID;

        public BestSellerReportExporter( string baseCurrencySymbol, string cultureID )
        {
            _baseCurrencySymbol = baseCurrencySymbol;
            _cultureID = cultureID;
        }

        private string GenerateHeader()
        {
            return "\"Name\"\t\"SKU\"\t\"Total Price\"\t" +
                   "\"Total Items Sold\"\t\"Unit Price\"";
        }

        private string GenerateDetail( DataRow row )
        {
            string name, sku, prodcutPrice, productQuantity, price;
            name = row["Name"].ToString();
            sku = row["SKU"].ToString();
            prodcutPrice = _baseCurrencySymbol + row["ProductPrice"].ToString();
            productQuantity = row["ProductQuantity"].ToString();
            price = _baseCurrencySymbol + row["Price"].ToString();

            return name + "\t" + sku + "\t" + prodcutPrice + "\t" + productQuantity + "\t" + price;
        }

        public string ExportBestSellerReportData(
            BestSellReportType bestSellReportType,
            PeriodType period,
            string numDisplay,
            string filePhysicalPath,
            string storeID,
            DateTime startDate,
            DateTime endDate,
            out string message,
            out string message1,
            out string fileNameLinkText
            )
        {
            string sort = String.Empty;
            if (bestSellReportType == BestSellReportType.NumberOfProduct)
            {
                sort = "ProductQuantity DESC";
            }
            else if (bestSellReportType == BestSellReportType.ProductTotalPrice)
            {
                sort = "ProductPrice DESC";
            }

            BestSellingReportBuilder reportBuilder = new BestSellingReportBuilder();
            DataTable table = reportBuilder.GetBestSellingReportData(
                sort,
                _cultureID,
                period,
                bestSellReportType,
                numDisplay,
                storeID,
                startDate,
                endDate );

            string filePathName = "Export/BestSelling_Top" +
                numDisplay + "_" +
                bestSellReportType + " Report_from_" +
                startDate.Month + "_" + startDate.Day + "_" + startDate.Year + "_to_" +
                endDate.Month + "_" + endDate.Day + "_" + endDate.Year + ".csv";

            string filePhysicalPathName = filePhysicalPath + filePathName;

            if (table.Rows.Count > 0)
            {
                StreamWriter writer = new StreamWriter( filePhysicalPathName, false, Encoding.Unicode );
                writer.WriteLine( GenerateHeader() );

                string details;
                foreach (DataRow row in table.Rows)
                {
                    details = GenerateDetail( row );
                    writer.WriteLine( details );
                }
                writer.Dispose();
            }
            if (table.Rows.Count == 0)
            {
                message = "No data to export.";
                message1 = "";
                fileNameLinkText = "";
                return "";
            }
            else
            {
                message = "Export file is successfully create.";
                message1 = "Download ";
                fileNameLinkText = Path.GetFileName( filePathName );
                return "../DownloadFile.aspx?FilePath=" + "../" + filePathName;
            }

        }
    }
}
