using System;
using System.Data;
using System.Collections.Generic;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Vevo.WebAppLib;
using Vevo.DataAccessLib.Cart;
using Vevo.Domain;
using Vevo.Domain.Orders;
using Vevo.Domain.Products;
using Vevo.Shared.DataAccess;
using Vevo.Shared.Utilities;
using Vevo.Shared.WebUI;

namespace Vevo.WebUI
{
    /// <summary>
    /// Summary description for DownloadKey
    /// </summary>
    public class DownloadKey
    {
        #region Public Enum Type

        public enum VerifyStatus
        {
            OK,
            UnknownError,
            Expired,
            InvalidProductID,
            InvalidUser,
            InvalidOrderItemID,
            OverDownloadLimit
        }

        #endregion

        #region Private

        string _productID = String.Empty;
        string _userName = String.Empty;
        string _orderItemID = String.Empty;
        string _secretKey = String.Empty;

        #endregion

        #region Constructors

        public DownloadKey( string productID, string userName, string orderItemID )
        {
            _productID = productID;
            _userName = userName;
            _orderItemID = orderItemID;
            _secretKey = DataAccessHelper.SecretKey;
        }

        public DownloadKey( string productID, string userName, string orderItemID, string secretKey )
        {
            _productID = productID;
            _userName = userName;
            _orderItemID = orderItemID;
            _secretKey = secretKey;
        }

        #endregion

        #region Public Method

        #endregion

        public string GetProductDownloadKey()
        {
            string expireDate =
                DateTime.Today.AddDays(
                DataAccessContext.Configurations.GetDoubleValue( "DownloadExpirePeriod" ) )
                .ToString( "d", CultureUtilities.USCultureInfo );

            string source = _productID + "|" + _userName + "|" + expireDate;
          
            if (_orderItemID != "0")
                source += "|" + _orderItemID;

            return SymmetricEncryption.Encrypt( source, _secretKey );
        }

        public VerifyStatus VerifyKey( string key, out string errorMessage )
        {
            errorMessage = String.Empty;
            try
            {
                string decoded = SymmetricEncryption.Decrypt( key, _secretKey );
                string[] decodeArray = decoded.Split( '|' );

                string decode_productID = decodeArray[0];
                string decode_userName = decodeArray[1];
                DateTime decode_expirationDate =
                    DateTime.Parse( decodeArray[2], CultureUtilities.USCultureInfo );

                if (String.Compare( decode_userName, _userName, false ) != 0)
                {
                    errorMessage =
                        "Invalid User. "
                        + "Please log in with the user account that purchased this product";
                    return VerifyStatus.InvalidUser;
                }

                if ((String.Compare( decode_productID, _productID, false ) != 0))
                {
                    errorMessage = "Invalid download URL.";
                    return VerifyStatus.InvalidProductID;
                }

                if (DateTime.Today > decode_expirationDate)
                {
                    errorMessage = "This download link has been expired.<br/><br/>";
                    return VerifyStatus.Expired;
                }

                if (_orderItemID != "0") //new link ?
                {
                    string decode_orderItemID = decodeArray[3];

                    if (String.Compare( decode_orderItemID, _orderItemID, false ) != 0)
                    {
                        errorMessage = "Invalid download URL.";
                        return VerifyStatus.InvalidOrderItemID;
                    }

                    if (!DataAccessContext.Configurations.GetBoolValue( "IsUnlimitDownload" ))
                    {
                        OrderItem item = DataAccessContext.OrderItemRepository.GetOne( _orderItemID );

                        if (item.DownloadCount >=
                            DataAccessContext.Configurations.GetIntValue( "NumberOfDownloadCount" ))
                        {
                            errorMessage = "This download link has been over download limit.<br/><br/>";
                            return VerifyStatus.OverDownloadLimit;
                        }
                    }

                }
                return VerifyStatus.OK;
            }
            catch (Exception ex)
            {
                errorMessage = "Error: " + ex.Message;
                return VerifyStatus.UnknownError;
            }
        }
    }
}
