using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using System.Xml;

using Vevo.Domain;
using Vevo.Domain.Users;

namespace Vevo.WebUI.Users
{
    /// <summary>
    /// Summary description for AddressUtilities
    /// </summary>
    public static class AddressUtilities
    {
        private static void CreateCountry( string countryCode, string commonName, string formalName,
            string countryType, string countrySubType, string sovereignty,
            string capital, string currencyCode, string currencyName, string telephoneCode,
            string countryCode3, string countryNumber, string internetCountryCode, int sortOrder )
        {
            Country country = new Country();
            country.CountryCode = countryCode;
            country.CommonName = commonName;
            country.FormalName = formalName;
            country.CountryType = countryType;
            country.CountrySubType = countrySubType;
            country.Sovereignty = sovereignty;
            country.Capital = capital;
            country.CurrencyCode = currencyCode;
            country.CurrencyName = currencyName;
            country.TelephoneCode = telephoneCode;
            country.CountryCode3 = countryCode3;
            country.CountryNumber = countryNumber;
            country.InternetCountryCode = internetCountryCode;
            country.SortOrder = sortOrder;
            country.Enabled = true;

            DataAccessContext.CountryRepository.Create( country );
        }

        private static void CreateState( string countryCode,
            string stateCode, string stateName, int sortOrder )
        {
            State state = new State();
            state.CountryCode = countryCode;
            state.StateCode = stateCode;
            state.StateName = stateName;
            state.SortOrder = sortOrder;
            state.Enabled = true;
            DataAccessContext.StateRepository.Create( state );
        }

        public static string GetStateNameByStateCode( string countryCode, string stateCode )
        {
            State state = DataAccessContext.StateRepository.GetOne( countryCode, stateCode );
            return String.Format( "{0} ({1})", state.StateName, stateCode );
        }

        public static string GetOnlyStateNameByStateCode( string countryCode, string stateCode )
        {
            State state = DataAccessContext.StateRepository.GetOne( countryCode, stateCode );
            if (!String.IsNullOrEmpty( state.StateName ))
                return state.StateName;
            else
                return stateCode;
        }

        public static string GetCountryNameByCountryCode( string code )
        {
            Country country = DataAccessContext.CountryRepository.GetOne( code );
            return String.Format( "{0} ({1})", country.CommonName, code );
        }

        public static string GetOnlyCountryNameByCountryCode( string code )
        {
            Country country = DataAccessContext.CountryRepository.GetOne( code );

            if (!String.IsNullOrEmpty( country.CommonName ))
                return country.CommonName;
            else
                return code;
        }

        public static void RestoreCountryCode()
        {
            DataAccessContext.CountryRepository.DeleteAll();

            CreateCountry( "AF", "Afghanistan", "Islamic State of Afghanistan", "Independent State", "", "", "Kabul",
                "AFN", "Afghani", "+93", "AFG", "004", ".af", 1 );

            CreateCountry( "AX", "Aland", "", "Proto Dependency", "", "Finland", "Mariehamn", "EUR", "Euro", "+358-18",
                "ALA", "248", ".ax", 2 );

            CreateCountry( "AL", "Albania", "Republic of Albania", "Independent State", "", "", "Tirana", "ALL", "Lek",
                "+355", "ALB", "008", ".al", 3 );

            CreateCountry( "DZ", "Algeria", "People's Democratic Republic of Algeria", "Independent State", "", "",
                "Algiers", "DZD", "Dinar", "+213", "DZA", "012", ".dz", 4 );

            CreateCountry( "AS", "American Samoa", "Territory of American Samoa", "Dependency", "Territory", "United States",
                "Pago Pago", "USD", "Dollar", "+1-684", "ASM", "016", ".as", 5 );

            CreateCountry( "AD", "Andorra", "Principality of Andorra", "Independent State", "", "", "Andorra la Vella", "EUR",
                "Euro", "+376", "AND", "020", ".ad", 6 );

            CreateCountry( "AO", "Angola", "Republic of Angola", "Independent State", "", "", "Luanda", "AOA", "Kwanza",
                "+244", "AGO", "024", ".ao", 7 );

            CreateCountry( "AI", "Anguilla", "", "Dependency", "Overseas Territory", "United Kingdom", "The Valley", "XCD",
                "Dollar", "+1-264", "AIA", "660", ".ai", 8 );

            CreateCountry( "AQ", "Antarctica", "", "Disputed Territory", "", "Undetermined", "", "", "", "", "ATA", "010", ".aq", 9 );

            CreateCountry( "AG", "Antigua and Barbuda", "", "Independent State", "", "", "Saint John's", "XCD", "Dollar", "+1-268",
                "ATG", "028", ".ag", 10 );

            CreateCountry( "AR", "Argentina", "Argentine Republic", "Independent State", "", "", "Buenos Aires", "ARS", "Peso", "+54",
                "ARG", "032", ".ar", 11 );

            CreateCountry( "AM", "Armenia", "Republic of Armenia", "Independent State", "", "", "Yerevan", "AMD", "Dram", "+374",
                "ARM", "051", ".am", 12 );

            CreateCountry( "AW", "Aruba", "", "Proto Dependency", "", "Netherlands", "Oranjestad", "AWG", "Guilder", "+297", "ABW",
                "533", ".aw", 13 );

            CreateCountry( "AC", "Ascension", "", "Proto Dependency", "Dependency of Saint Helena", "United Kingdom", "Georgetown",
                "SHP", "Pound", "+247", "ASC", "", ".ac", 14 );

            CreateCountry( "AU", "Australia", "Commonwealth of Australia", "Independent State", "", "", "Canberra", "AUD", "Dollar",
                "+61", "AUS", "036", ".au", 15 );

            CreateCountry( "AT", "Austria", "Republic of Austria", "Independent State", "", "", "Vienna", "EUR", "Euro", "+43", "AUT",
                "040", ".at", 16 );

            CreateCountry( "AZ", "Azerbaijan", "Republic of Azerbaijan", "Independent State", "", "", "Baku", "AZN", "Manat", "+994",
                "AZE", "031", ".az", 17 );

            CreateCountry( "BS", "Bahamas, The", "Commonwealth of The Bahamas", "Independent State", "", "", "Nassau", "BSD", "Dollar",
                "+1-242", "BHS", "044", ".bs", 18 );

            CreateCountry( "BH", "Bahrain", "Kingdom of Bahrain", "Independent State", "", "", "Manama", "BHD", "Dinar", "+973", "BHR",
                "048", ".bh", 19 );

            CreateCountry( "BD", "Bangladesh", "People's Republic of Bangladesh", "Independent State", "", "", "Dhaka", "BDT", "Taka",
                "+880", "BGD", "050", ".bd", 20 );

            CreateCountry( "BB", "Barbados", "", "Independent State", "", "", "Bridgetown", "BBD", "Dollar", "+1-246", "BRB", "052",
                ".bb", 21 );

            CreateCountry( "BY", "Belarus", "Republic of Belarus", "Independent State", "", "", "Minsk", "BYR", "Ruble", "+375", "BLR",
                "112", ".by", 22 );

            CreateCountry( "BE", "Belgium", "Kingdom of Belgium", "Independent State", "", "", "Brussels", "EUR", "Euro", "+32", "BEL",
                "056", ".be", 23 );

            CreateCountry( "BZ", "Belize", "", "Independent State", "", "", "Belmopan", "BZD", "Dollar", "+501", "BLZ", "084",
                ".bz", 24 );

            CreateCountry( "BJ", "Benin", "Republic of Benin", "Independent State", "", "", "Porto-Novo", "XOF", "Franc", "+229",
                "BEN", "204", ".bj", 25 );

            CreateCountry( "BM", "Bermuda", "", "Dependency", "Overseas Territory", "United Kingdom", "Hamilton", "BMD", "Dollar",
                "+1-441", "BMU", "060", ".bm", 26 );

            CreateCountry( "BT", "Bhutan", "Kingdom of Bhutan", "Independent State", "", "", "Thimphu", "BTN", "Ngultrum", "+975",
                "BTN", "064", ".bt", 27 );

            CreateCountry( "BO", "Bolivia", "Republic of Bolivia", "Independent State", "", "",
                "La Paz (administrative/legislative) and Sucre (judical)", "BOB", "Boliviano", "+591", "BOL", "068", ".bo", 28 );

            CreateCountry( "BA", "Bosnia and Herzegovina", "", "Independent State", "", "", "Sarajevo", "BAM", "Marka", "+387",
                "BIH", "070", ".ba", 29 );

            CreateCountry( "BW", "Botswana", "Republic of Botswana", "Independent State", "", "", "Gaborone", "BWP", "Pula", "+267",
                "BWA", "072", ".bw", 30 );

            CreateCountry( "BV", "Bouvet Island", "", "Dependency", "Territory", "Norway", "", "", "", "", "BVT", "074", ".bv", 31 );

            CreateCountry( "BR", "Brazil", "Federative Republic of Brazil", "Independent State", "", "", "Brasilia", "BRL", "Real",
                "+55", "BRA", "076", ".br", 32 );

            CreateCountry( "IO", "British Indian Ocean Territory", "", "Dependency", "Overseas Territory", "United Kingdom", "", "", "",
                "+246", "IOT", "086", ".io", 33 );

            CreateCountry( "VG", "British Virgin Islands", "", "Dependency", "Overseas Territory", "United Kingdom", "Road Town",
                "USD", "Dollar", "+1-284", "VGB", "092", ".vg", 34 );

            CreateCountry( "BN", "Brunei", "Negara Brunei Darussalam", "Independent State", "", "", "Bandar Seri Begawan", "BND",
                "Dollar", "+673", "BRN", "096", ".bn", 35 );

            CreateCountry( "BG", "Bulgaria", "Republic of Bulgaria", "Independent State", "", "", "Sofia", "BGN", "Lev", "+359",
                "BGR", "100", ".bg", 36 );

            CreateCountry( "BF", "Burkina Faso", "", "Independent State", "", "", "Ouagadougou", "XOF", "Franc", "+226", "BFA",
                "854", ".bf", 37 );

            CreateCountry( "BI", "Burundi", "Republic of Burundi", "Independent State", "", "", "Bujumbura", "BIF", "Franc", "+257",
                "BDI", "108", ".bi", 38 );

            CreateCountry( "KH", "Cambodia", "Kingdom of Cambodia", "Independent State", "", "", "Phnom Penh", "KHR", "Riels",
                "+855", "KHM", "116", ".kh", 39 );

            CreateCountry( "CM", "Cameroon", "Republic of Cameroon", "Independent State", "", "", "Yaounde", "XAF", "Franc",
                "+237", "CMR", "120", ".cm", 40 );

            CreateCountry( "CA", "Canada", "", "Independent State", "", "", "Ottawa", "CAD", "Dollar", "+1", "CAN", "124", ".ca", 41 );

            CreateCountry( "CV", "Cape Verde", "Republic of Cape Verde", "Independent State", "", "", "Praia", "CVE", "Escudo",
                "+238", "CPV", "132", ".cv", 42 );

            CreateCountry( "KY", "Cayman Islands", "", "Dependency", "Overseas Territory", "United Kingdom", "George Town", "KYD",
                "Dollar", "+1-345", "CYM", "136", ".ky", 43 );

            CreateCountry( "CF", "Central African Republic", "", "Independent State", "", "", "Bangui", "XAF", "Franc", "+236",
                "CAF", "140", ".cf", 44 );

            CreateCountry( "TD", "Chad", "Republic of Chad", "Independent State", "", "", "N'Djamena", "XAF", "Franc", "+235",
                "TCD", "148", ".td", 45 );

            CreateCountry( "CL", "Chile", "Republic of Chile", "Independent State", "", "",
                "Santiago (administrative/judical) and Valparaiso (legislative)", "CLP", "Peso", "+56", "CHL", "152", ".cl", 46 );

            CreateCountry( "CN", "China, People's Republic of", "People's Republic of China", "Independent State", "", "",
                "Beijing", "CNY", "Yuan Renminbi", "+86", "CHN", "156", ".cn", 47 );

            CreateCountry( "TW", "China, Republic of (Taiwan)", "Republic of China", "Proto Independent State", "", "", "Taipei",
                "TWD", "Dollar", "+886", "TWN", "158", ".tw", 48 );

            CreateCountry( "CX", "Christmas Island", "Territory of Christmas Island", "Dependency", "External Territory",
                "Australia", "The Settlement (Flying Fish Cove)", "AUD", "Dollar", "+61", "CXR", "162", ".cx", 49 );

            CreateCountry( "CC", "Cocos (Keeling) Islands", "Territory of Cocos (Keeling) Islands", "Dependency",
                "External Territory", "Australia", "West Island", "AUD", "Dollar", "+61", "CCK", "166", ".cc", 50 );

            CreateCountry( "CO", "Colombia", "Republic of Colombia", "Independent State", "", "", "Bogota", "COP", "Peso",
                "+57", "COL", "170", ".co", 51 );

            CreateCountry( "KM", "Comoros", "Union of Comoros", "Independent State", "", "", "Moroni", "KMF", "Franc", "+269",
                "COM", "174", ".km", 52 );

            CreateCountry( "CG", "Congo ? Brazzaville", "Republic of the Congo", "Independent State", "", "", "Brazzaville",
                "XAF", "Franc", "+242", "COG", "178", ".cg", 53 );

            CreateCountry( "CD", "Congo ? Kinshasa", "Democratic Republic of the Congo", "Independent State", "", "", "Kinshasa",
                "CDF", "Franc", "+243", "COD", "180", ".cd", 54 );

            CreateCountry( "CK", "Cook Islands", "", "Dependency", "Self-Governing in Free Association", "New Zealand", "Avarua",
                "NZD", "Dollar", "+682", "COK", "184", ".ck", 55 );

            CreateCountry( "CR", "Costa Rica", "Republic of Costa Rica", "Independent State", "", "", "San Jose", "CRC", "Colon",
                "+506", "CRI", "188", ".cr", 56 );

            CreateCountry( "CI", "Cote d'Ivoire (Ivory Coast)", "Republic of Cote d'Ivoire", "Independent State", "", "",
                "Yamoussoukro", "XOF", "Franc", "+225", "CIV", "384", ".ci", 57 );

            CreateCountry( "HR", "Croatia", "Republic of Croatia", "Independent State", "", "", "Zagreb", "HRK", "Kuna", "+385",
                "HRV", "191", ".hr", 58 );

            CreateCountry( "CU", "Cuba", "Republic of Cuba", "Independent State", "", "", "Havana", "CUP", "Peso", "+53", "CUB",
                "192", ".cu", 59 );

            CreateCountry( "CY", "Cyprus", "Republic of Cyprus", "Independent State", "", "", "Nicosia", "CYP", "Pound", "+357",
                "CYP", "196", ".cy", 60 );

            CreateCountry( "CZ", "Czech Republic", "", "Independent State", "", "", "Prague", "CZK", "Koruna", "+420", "CZE",
                "203", ".cz", 61 );

            CreateCountry( "DK", "Denmark", "Kingdom of Denmark", "Independent State", "", "", "Copenhagen", "DKK", "Krone",
                "+45", "DNK", "208", ".dk", 62 );

            CreateCountry( "DJ", "Djibouti", "Republic of Djibouti", "Independent State", "", "", "Djibouti", "DJF", "Franc",
                "+253", "DJI", "262", ".dj", 63 );

            CreateCountry( "DM", "Dominica", "Commonwealth of Dominica", "Independent State", "", "", "Roseau", "XCD", "Dollar",
                "+1-767", "DMA", "212", ".dm", 64 );

            CreateCountry( "DO", "Dominican Republic", "", "Independent State", "", "", "Santo Domingo", "DOP", "Peso",
                "+1-809 and 1-829", "DOM", "214", ".do", 65 );

            CreateCountry( "EC", "Ecuador", "Republic of Ecuador", "Independent State", "", "", "Quito", "USD", "Dollar",
                "+593", "ECU", "218", ".ec", 66 );

            CreateCountry( "EG", "Egypt", "Arab Republic of Egypt", "Independent State", "", "", "Cairo", "EGP", "Pound",
                "+20", "EGY", "818", ".eg", 67 );

            CreateCountry( "SV", "El Salvador", "Republic of El Salvador", "Independent State", "", "", "San Salvador", "USD",
                "Dollar", "+503", "SLV", "222", ".sv", 68 );

            CreateCountry( "GQ", "Equatorial Guinea", "Republic of Equatorial Guinea", "Independent State", "", "", "Malabo",
                "XAF", "Franc", "+240", "GNQ", "226", ".gq", 69 );

            CreateCountry( "ER", "Eritrea", "State of Eritrea", "Independent State", "", "", "Asmara", "ERN", "Nakfa", "+291",
                "ERI", "232", ".er", 70 );

            CreateCountry( "EE", "Estonia", "Republic of Estonia", "Independent State", "", "", "Tallinn", "EEK", "Kroon",
                "+372", "EST", "233", ".ee", 71 );

            CreateCountry( "ET", "Ethiopia", "Federal Democratic Republic of Ethiopia", "Independent State", "", "",
                "Addis Ababa", "ETB", "Birr", "+251", "ETH", "231", ".et", 72 );

            CreateCountry( "FK", "Falkland Islands", "", "Dependency", "Overseas Territory", "United Kingdom", "Stanley",
                "FKP", "Pound", "+500", "FLK", "238", ".fk", 73 );

            CreateCountry( "FO", "Faroe Islands", "", "Proto Dependency", "", "Denmark", "Torshavn", "DKK", "Krone", "+298",
                "FRO", "234", ".fo", 74 );

            CreateCountry( "FJ", "Fiji", "Republic of the Fiji Islands", "Independent State", "", "", "Suva", "FJD", "Dollar",
                "+679", "FJI", "242", ".fj", 75 );

            CreateCountry( "FI", "Finland", "Republic of Finland", "Independent State", "", "", "Helsinki", "EUR", "Euro",
                "+358", "FIN", "246", ".fi", 76 );

            CreateCountry( "FR", "France", "French Republic", "Independent State", "", "", "Paris", "EUR", "Euro", "+33", "FRA",
                "250", ".fr", 77 );

            CreateCountry( "GF", "French Guiana", "Overseas Region of Guiana", "Proto Dependency", "Overseas Region", "France",
                "Cayenne", "EUR", "Euro", "+594", "GUF", "254", ".gf", 78 );

            CreateCountry( "PF", "French Polynesia", "Overseas Country of French Polynesia", "Dependency", "Overseas Collectivity",
                "France", "Papeete", "XPF", "Franc", "+689", "PYF", "258", ".pf", 79 );

            CreateCountry( "TF", "French Southern Territories", "Territory of the French Southern and Antarctic Lands",
                "Dependency", "Overseas Territory", "France", "Martin-de-Vivi?s", "", "", "", "ATF", "260", ".tf", 80 );

            CreateCountry( "GA", "Gabon", "Gabonese Republic", "Independent State", "", "", "Libreville", "XAF", "Franc", "+241",
                "GAB", "266", ".ga", 81 );

            CreateCountry( "GM", "Gambia, The", "Republic of The Gambia", "Independent State", "", "", "Banjul", "GMD", "Dalasi",
                "+220", "GMB", "270", ".gm", 82 );

            CreateCountry( "GE", "Georgia", "Republic of Georgia", "Independent State", "", "", "Tbilisi", "GEL", "Lari", "+995",
                "GEO", "268", ".ge", 83 );

            CreateCountry( "DE", "Germany", "Federal Republic of Germany", "Independent State", "", "", "Berlin", "EUR", "Euro",
                "+49", "DEU", "276", ".de", 84 );

            CreateCountry( "GH", "Ghana", "Republic of Ghana", "Independent State", "", "", "Accra", "GHC", "Cedi", "+233", "GHA",
                "288", ".gh", 85 );

            CreateCountry( "GI", "Gibraltar", "", "Dependency", "Overseas Territory", "United Kingdom", "Gibraltar", "GIP",
                "Pound", "+350", "GIB", "292", ".gi", 86 );

            CreateCountry( "GR", "Greece", "Hellenic Republic", "Independent State", "", "", "Athens", "EUR", "Euro", "+30",
                "GRC", "300", ".gr", 87 );

            CreateCountry( "GL", "Greenland", "", "Proto Dependency", "", "Denmark", "Nuuk (Godthab)", "DKK", "Krone", "+299",
                "GRL", "304", ".gl", 88 );

            CreateCountry( "GD", "Grenada", "", "Independent State", "", "", "Saint George's", "XCD", "Dollar", "+1-473", "GRD",
                "308", ".gd", 89 );

            CreateCountry( "GU", "Guam", "Territory of Guam", "Dependency", "Territory", "United States", "Hagatna", "USD",
                "Dollar", "+1-671", "GUM", "316", ".gu", 90 );

            CreateCountry( "GT", "Guatemala", "Republic of Guatemala", "Independent State", "", "", "Guatemala", "GTQ",
                "Quetzal", "+502", "GTM", "320", ".gt", 91 );

            CreateCountry( "GG", "Guernsey", "Bailiwick of Guernsey", "Dependency", "Crown Dependency", "United Kingdom",
                "Saint Peter Port", "GGP", "Pound", "+44", "GGY", "831", ".gg", 92 );

            CreateCountry( "GN", "Guinea", "Republic of Guinea", "Independent State", "", "", "Conakry", "GNF", "Franc",
                "+224", "GIN", "324", ".gn", 93 );

            CreateCountry( "GW", "Guinea-Bissau", "Republic of Guinea-Bissau", "Independent State", "", "", "Bissau", "XOF",
                "Franc", "+245", "GNB", "624", ".gw", 94 );

            CreateCountry( "GY", "Guyana", "Co-operative Republic of Guyana", "Independent State", "", "", "Georgetown",
                "GYD", "Dollar", "+592", "GUY", "328", ".gy", 95 );

            CreateCountry( "HT", "Haiti", "Republic of Haiti", "Independent State", "", "", "Port-au-Prince", "HTG", "Gourde",
                "+509", "HTI", "332", ".ht", 96 );

            CreateCountry( "HM", "Heard and McDonald Islands", "Territory of Heard Island and McDonald Islands", "Dependency",
                "External Territory", "Australia", "", "", "", "", "HMD", "334", ".hm", 97 );

            CreateCountry( "HN", "Honduras", "Republic of Honduras", "Independent State", "", "", "Tegucigalpa", "HNL", "Lempira",
                "+504", "HND", "340", ".hn", 98 );

            CreateCountry( "HK", "Hong Kong", "Hong Kong Special Administrative Region", "Proto Dependency",
                "Special Administrative Region", "China", "", "HKD", "Dollar", "+852", "HKG", "344", ".hk", 99 );

            CreateCountry( "HU", "Hungary", "Republic of Hungary", "Independent State", "", "", "Budapest", "HUF", "Forint",
                "+36", "HUN", "348", ".hu", 100 );

            CreateCountry( "IS", "Iceland", "Republic of Iceland", "Independent State", "", "", "Reykjavik", "ISK", "Krona",
                "+354", "ISL", "352", ".is", 101 );

            CreateCountry( "IN", "India", "Republic of India", "Independent State", "", "", "New Delhi", "INR", "Rupee", "+91",
                "IND", "356", ".in", 102 );

            CreateCountry( "ID", "Indonesia", "Republic of Indonesia", "Independent State", "", "", "Jakarta", "IDR", "Rupiah",
                "+62", "IDN", "360", ".id", 103 );

            CreateCountry( "IR", "Iran", "Islamic Republic of Iran", "Independent State", "", "", "Tehran", "IRR", "Rial",
                "+98", "IRN", "364", ".ir", 104 );

            CreateCountry( "IQ", "Iraq", "Republic of Iraq", "Independent State", "", "", "Baghdad", "IQD", "Dinar", "+964",
                "IRQ", "368", ".iq", 105 );

            CreateCountry( "IE", "Ireland", "", "Independent State", "", "", "Dublin", "EUR", "Euro", "+353", "IRL", "372",
                ".ie", 106 );

            CreateCountry( "IM", "Isle of Man", "", "Dependency", "Crown Dependency", "United Kingdom", "Douglas", "IMP",
                "Pound", "+44", "IMN", "833", ".im", 107 );

            CreateCountry( "IL", "Israel", "State of Israel", "Independent State", "", "", "Jerusalem", "ILS", "Shekel", "+972",
                "ISR", "376", ".il", 108 );

            CreateCountry( "IT", "Italy", "Italian Republic", "Independent State", "", "", "Rome", "EUR", "Euro", "+39", "ITA",
                "380", ".it", 109 );

            CreateCountry( "JM", "Jamaica", "", "Independent State", "", "", "Kingston", "JMD", "Dollar", "+1-876", "JAM",
                "388", ".jm", 110 );

            CreateCountry( "JP", "Japan", "", "Independent State", "", "", "Tokyo", "JPY", "Yen", "+81", "JPN", "392", ".jp", 111 );

            CreateCountry( "JE", "Jersey", "Bailiwick of Jersey", "Dependency", "Crown Dependency", "United Kingdom",
                "Saint Helier", "JEP", "Pound", "+44", "JEY", "832", ".je", 112 );

            CreateCountry( "JO", "Jordan", "Hashemite Kingdom of Jordan", "Independent State", "", "", "Amman", "JOD",
                "Dinar", "+962", "JOR", "400", ".jo", 113 );

            CreateCountry( "KZ", "Kazakhstan", "Republic of Kazakhstan", "Independent State", "", "", "Astana", "KZT",
                "Tenge", "+7", "KAZ", "398", ".kz", 114 );

            CreateCountry( "KE", "Kenya", "Republic of Kenya", "Independent State", "", "", "Nairobi", "KES", "Shilling",
                "+254", "KEN", "404", ".ke", 115 );

            CreateCountry( "KI", "Kiribati", "Republic of Kiribati", "Independent State", "", "", "Tarawa", "AUD", "Dollar",
                "+686", "KIR", "296", ".ki", 116 );

            CreateCountry( "KP", "Korea(North Korea)", "Democratic People's Republic of Korea", "Independent State", "", "",
                "Pyongyang", "KPW", "Won", "+850", "PRK", "408", ".kp", 117 );

            CreateCountry( "KR", "Korea(South Korea)", "Republic of Korea", "Independent State", "", "", "Seoul", "KRW",
                "Won", "+82", "KOR", "410", ".kr", 118 );

            CreateCountry( "CS", "Kosovo", "", "Disputed Territory", "", "Administrated by the UN", "Pristina",
                "CSD and EUR", "Dinar and Euro", "+381", "SCG", "891", ".cs and .yu", 119 );

            CreateCountry( "KW", "Kuwait", "State of Kuwait", "Independent State", "", "", "Kuwait", "KWD", "Dinar",
                "+965", "KWT", "414", ".kw", 120 );

            CreateCountry( "KG", "Kyrgyzstan", "Kyrgyz Republic", "Independent State", "", "", "Bishkek", "KGS",
                "Som", "+996", "KGZ", "417", ".kg", 121 );

            CreateCountry( "LA", "Laos", "Lao People's Democratic Republic", "Independent State", "", "",
                "Vientiane", "LAK", "Kip", "+856", "LAO", "418", ".la", 122 );

            CreateCountry( "LV", "Latvia", "Republic of Latvia", "Independent State", "", "", "Riga", "LVL",
                "Lat", "+371", "LVA", "428", ".lv", 123 );

            CreateCountry( "LB", "Lebanon", "Lebanese Republic", "Independent State", "", "", "Beirut", "LBP",
                "Pound", "+961", "LBN", "422", ".lb", 124 );

            CreateCountry( "LS", "Lesotho", "Kingdom of Lesotho", "Independent State", "", "", "Maseru", "LSL",
                "Loti", "+266", "LSO", "426", ".ls", 125 );

            CreateCountry( "LR", "Liberia", "Republic of Liberia", "Independent State", "", "", "Monrovia", "LRD",
                "Dollar", "+231", "LBR", "430", ".lr", 126 );

            CreateCountry( "LY", "Libya", "Great Socialist People's Libyan Arab Jamahiriya", "Independent State",
                "", "", "Tripoli", "LYD", "Dinar", "+218", "LBY", "434", ".ly", 127 );

            CreateCountry( "LI", "Liechtenstein", "Principality of Liechtenstein", "Independent State", "", "",
                "Vaduz", "CHF", "Franc", "+423", "LIE", "438", ".li", 128 );

            CreateCountry( "LT", "Lithuania", "Republic of Lithuania", "Independent State", "", "", "Vilnius",
                "LTL", "Litas", "+370", "LTU", "440", ".lt", 129 );

            CreateCountry( "LU", "Luxembourg", "Grand Duchy of Luxembourg", "Independent State", "", "",
                "Luxembourg", "EUR", "Euro", "+352", "LUX", "442", ".lu", 130 );

            CreateCountry( "MO", "Macau", "Macau Special Administrative Region", "Proto Dependency",
                "Special Administrative Region", "China", "Macau", "MOP", "Pataca", "+853", "MAC", "446", ".mo", 131 );

            CreateCountry( "MK", "Macedonia", "Republic of Macedonia", "Independent State", "", "", "Skopje",
                "MKD", "Denar", "+389", "MKD", "807", ".mk", 132 );

            CreateCountry( "MG", "Madagascar", "Republic of Madagascar", "Independent State", "", "", "Antananarivo",
                "MGA", "Ariary", "+261", "MDG", "450", ".mg", 133 );

            CreateCountry( "MW", "Malawi", "Republic of Malawi", "Independent State", "", "", "Lilongwe", "MWK", "Kwacha",
                "+265", "MWI", "454", ".mw", 134 );

            CreateCountry(
                "MY", "Malaysia", "", "Independent State", "", "", "Kuala Lumpur (legislative/judical) and Putrajaya (administrative)",
                "MYR", "Ringgit", "+60", "MYS", "458", ".my", 135 );

            CreateCountry( "MV", "Maldives", "Republic of Maldives", "Independent State", "", "", "Male", "MVR", "Rufiyaa",
                "+960", "MDV", "462", ".mv", 136 );

            CreateCountry( "ML", "Mali", "Republic of Mali", "Independent State", "", "", "Bamako", "XOF", "Franc", "+223",
                "MLI", "466", ".ml", 137 );

            CreateCountry( "MT", "Malta", "Republic of Malta", "Independent State", "", "", "Valletta", "MTL", "Lira",
                "+356", "MLT", "470", ".mt", 138 );

            CreateCountry( "MH", "Marshall Islands", "Republic of the Marshall Islands", "Independent State", "", "",
                "Majuro", "USD", "Dollar", "+692", "MHL", "584", ".mh", 139 );

            CreateCountry( "MQ", "Martinique", "Overseas Region of Martinique", "Proto Dependency", "Overseas Region",
                "France", "Fort-de-France", "EUR", "Euro", "+596", "MTQ", "474", ".mq", 140 );

            CreateCountry( "MR", "Mauritania", "Islamic Republic of Mauritania", "Independent State", "", "",
                "Nouakchott", "MRO", "Ouguiya", "+222", "MRT", "478", ".mr", 141 );

            CreateCountry( "MU", "Mauritius", "Republic of Mauritius", "Independent State", "", "", "Port Louis",
                "MUR", "Rupee", "+230", "MUS", "480", ".mu", 142 );

            CreateCountry( "YT", "Mayotte", "Departmental Collectivity of Mayotte", "Dependency", "Overseas Collectivity",
                "France", "Mamoudzou", "EUR", "Euro", "+262", "MYT", "175", ".yt", 143 );

            CreateCountry( "MX", "Mexico", "United Mexican States", "Independent State", "", "", "Mexico", "MXN", "Peso",
                "+52", "MEX", "484", ".mx", 144 );

            CreateCountry( "FM", "Micronesia", "Federated States of Micronesia", "Independent State", "", "", "Palikir",
                "USD", "Dollar", "+691", "FSM", "583", ".fm", 145 );

            CreateCountry( "MD", "Moldova", "Republic of Moldova", "Independent State", "", "", "Chisinau", "MDL", "Leu",
                "+373", "MDA", "498", ".md", 146 );

            CreateCountry( "MC", "Monaco", "Principality of Monaco", "Independent State", "", "", "Monaco", "EUR", "Euro",
                "+377", "MCO", "492", ".mc", 147 );

            CreateCountry( "MN", "Mongolia", "", "Independent State", "", "", "Ulaanbaatar", "MNT", "Tugrik", "+976",
                "MNG", "496", ".mn", 148 );

            CreateCountry( "ME", "Montenegro", "Republic of Montenegro", "Independent State", "", "", "Podgorica",
                "EUR", "Euro", "+382", "MNE", "499", ".me and .yu", 149 );

            CreateCountry( "MS", "Montserrat", "", "Dependency", "Overseas Territory", "United Kingdom", "Plymouth",
                "XCD", "Dollar", "+1-664", "MSR", "500", ".ms", 150 );

            CreateCountry( "MA", "Morocco", "Kingdom of Morocco", "Independent State", "", "", "Rabat", "MAD", "Dirham",
                "+212", "MAR", "504", ".ma", 151 );

            CreateCountry( "MZ", "Mozambique", "Republic of Mozambique", "Independent State", "", "", "Maputo", "MZM",
                "Meticail", "+258", "MOZ", "508", ".mz", 152 );

            CreateCountry( "MM", "Myanmar (Burma)", "Union of Myanmar", "Independent State", "", "", "Naypyidaw", "MMK",
                "Kyat", "+95", "MMR", "104", ".mm", 153 );

            CreateCountry( "NA", "Namibia", "Republic of Namibia", "Independent State", "", "", "Windhoek", "NAD",
                "Dollar", "+264", "NAM", "516", ".na", 154 );

            CreateCountry( "NR", "Nauru", "Republic of Nauru", "Independent State", "", "", "Yaren", "AUD", "Dollar",
                "+674", "NRU", "520", ".nr", 155 );

            CreateCountry( "NP", "Nepal", "", "Independent State", "", "", "Kathmandu", "NPR", "Rupee", "+977", "NPL",
                "524", ".np", 156 );

            CreateCountry( "NL", "Netherlands", "Kingdom of the Netherlands", "Independent State", "", "",
                "Amsterdam (administrative) and The Hague (legislative/judical)", "EUR", "Euro", "+31", "NLD", "528", ".nl", 157 );

            CreateCountry( "AN", "Netherlands Antilles", "", "Proto Dependency", "", "Netherlands", "Willemstad",
                "ANG", "Guilder", "+599", "ANT", "530", ".an", 158 );

            CreateCountry( "NC", "New Caledonia", "", "Dependency", "Sui generis Collectivity", "France", "Noumea",
                "XPF", "Franc", "+687", "NCL", "540", ".nc", 159 );

            CreateCountry( "NZ", "New Zealand", "", "Independent State", "", "", "Wellington", "NZD", "Dollar", "+64",
                "NZL", "554", ".nz", 160 );

            CreateCountry( "NI", "Nicaragua", "Republic of Nicaragua", "Independent State", "", "", "Managua", "NIO",
                "Cordoba", "+505", "NIC", "558", ".ni", 161 );

            CreateCountry( "NE", "Niger", "Republic of Niger", "Independent State", "", "", "Niamey", "XOF", "Franc",
                "+227", "NER", "562", ".ne", 162 );

            CreateCountry( "NG", "Nigeria", "Federal Republic of Nigeria", "Independent State", "", "", "Abuja", "NGN",
                "Naira", "+234", "NGA", "566", ".ng", 163 );

            CreateCountry( "NU", "Niue", "", "Dependency", "Self-Governing in Free Association", "New Zealand", "Alofi",
                "NZD", "Dollar", "+683", "NIU", "570", ".nu", 164 );

            CreateCountry( "NF", "Norfolk Island", "Territory of Norfolk Island", "Dependency", "External Territory",
                "Australia", "Kingston", "AUD", "Dollar", "+672", "NFK", "574", ".nf", 165 );

            CreateCountry( "MP", "Northern Mariana Islands", "Commonwealth of The Northern Mariana Islands", "Dependency",
                "Commonwealth", "United States", "Saipan", "USD", "Dollar", "+1-670", "MNP", "580", ".mp", 166 );

            CreateCountry( "NO", "Norway", "Kingdom of Norway", "Independent State", "", "", "Oslo", "NOK", "Krone", "+47",
                "NOR", "578", ".no", 167 );

            CreateCountry( "OM", "Oman", "Sultanate of Oman", "Independent State", "", "", "Muscat", "OMR", "Rial",
                "+968", "OMN", "512", ".om", 168 );

            CreateCountry( "PK", "Pakistan", "Islamic Republic of Pakistan", "Independent State", "", "",
                "Islamabad", "PKR", "Rupee", "+92", "PAK", "586", ".pk", 169 );

            CreateCountry( "PW", "Palau", "Republic of Palau", "Independent State", "", "", "Melekeok", "USD",
                "Dollar", "+680", "PLW", "585", ".pw", 170 );

            CreateCountry( "PS", "Palestinian Territories", "", "Disputed Territory", "", "Administrated by Israel",
                "Gaza City (Gaza Strip) and Ramallah (West Bank)", "ILS", "Shekel", "+970", "PSE", "275", ".ps", 171 );

            CreateCountry( "PA", "Panama", "Republic of Panama", "Independent State", "", "", "Panama", "PAB", "Balboa",
                "+507", "PAN", "591", ".pa", 172 );

            CreateCountry( "PG", "Papua New Guinea", "Independent State of Papua New Guinea", "Independent State", "", "",
                "Port Moresby", "PGK", "Kina", "+675", "PNG", "598", ".pg", 173 );

            CreateCountry( "PY", "Paraguay", "Republic of Paraguay", "Independent State", "", "", "Asuncion", "PYG",
                "Guarani", "+595", "PRY", "600", ".py", 174 );

            CreateCountry( "PE", "Peru", "Republic of Peru", "Independent State", "", "", "Lima", "PEN", "Sol", "+51",
                "PER", "604", ".pe", 175 );

            CreateCountry( "PH", "Philippines", "Republic of the Philippines", "Independent State", "", "", "Manila",
                "PHP", "Peso", "+63", "PHL", "608", ".ph", 176 );

            CreateCountry( "PN", "Pitcairn Islands", "", "Dependency", "Overseas Territory", "United Kingdom", "Adamstown",
                "NZD", "Dollar", "", "PCN", "612", ".pn", 177 );

            CreateCountry( "PL", "Poland", "Republic of Poland", "Independent State", "", "", "Warsaw", "PLN", "Zloty",
                "+48", "POL", "616", ".pl", 178 );

            CreateCountry( "PT", "Portugal", "Portuguese Republic", "Independent State", "", "", "Lisbon", "EUR", "Euro",
                "+351", "PRT", "620", ".pt", 179 );

            CreateCountry( "PR", "Puerto Rico", "Commonwealth of Puerto Rico", "Dependency", "Commonwealth", "United States",
                "San Juan", "USD", "Dollar", "+1-787 and 1-939", "PRI", "630", ".pr", 180 );

            CreateCountry( "QA", "Qatar", "State of Qatar", "Independent State", "", "", "Doha", "QAR", "Rial", "+974",
                "QAT", "634", ".qa", 181 );

            CreateCountry( "RE", "Reunion", "Overseas Region of Reunion", "Proto Dependency", "Overseas Region", "France",
                "Saint-Denis", "EUR", "Euro", "+262", "REU", "638", ".re", 182 );

            CreateCountry( "RO", "Romania", "", "Independent State", "", "", "Bucharest", "RON", "Leu", "+40", "ROU",
                "642", ".ro", 183 );

            CreateCountry( "RU", "Russia", "Russian Federation", "Independent State", "", "", "Moscow", "RUB", "Ruble",
                "+7", "RUS", "643", ".ru and .su", 184 );

            CreateCountry( "RW", "Rwanda", "Republic of Rwanda", "Independent State", "", "", "Kigali", "RWF", "Franc",
                "+250", "RWA", "646", ".rw", 185 );

            CreateCountry( "SH", "Saint Helena", "", "Dependency", "Overseas Territory", "United Kingdom", "Jamestown",
                "SHP", "Pound", "+290", "SHN", "654", ".sh", 186 );

            CreateCountry( "KN", "Saint Kitts and Nevis", "Federation of Saint Kitts and Nevis", "Independent State", "", "",
                "Basseterre", "XCD", "Dollar", "+1-869", "KNA", "659", ".kn", 187 );

            CreateCountry( "LC", "Saint Lucia", "", "Independent State", "", "", "Castries", "XCD", "Dollar", "+1-758",
                "LCA", "662", ".lc", 188 );

            CreateCountry( "PM", "Saint Pierre and Miquelon", "Territorial Collectivity of Saint Pierre and Miquelon", "Dependency",
                 "Overseas Collectivity", "France", "Saint-Pierre", "EUR", "Euro", "+508", "SPM", "666", ".pm", 189 );

            CreateCountry( "WS", "Samoa", "Independent State of Samoa", "Independent State", "", "", "Apia", "WST",
                "Tala", "+685", "WSM", "882", ".ws", 190 );

            CreateCountry( "SM", "San Marino", "Republic of San Marino", "Independent State", "", "", "San Marino",
                "EUR", "Euro", "+378", "SMR", "674", ".sm", 191 );

            CreateCountry( "ST", "Sao Tome and Principe", "Democratic Republic of Sao Tome and Principe",
                "Independent State", "", "", "Sao Tome", "STD", "Dobra", "+239", "STP", "678", ".st", 192 );

            CreateCountry( "SA", "Saudi Arabia", "Kingdom of Saudi Arabia", "Independent State", "", "", "Riyadh",
                "SAR", "Rial", "+966", "SAU", "682", ".sa", 193 );

            CreateCountry( "SN", "Senegal", "Republic of Senegal", "Independent State", "", "", "Dakar", "XOF",
                "Franc", "+221", "SEN", "686", ".sn", 194 );

            CreateCountry( "RS", "Serbia", "Republic of Serbia", "Independent State", "", "", "Belgrade", "RSD",
                "Dinar", "+381", "SRB", "688", ".rs and .yu", 195 );

            CreateCountry( "SC", "Seychelles", "Republic of Seychelles", "Independent State", "", "", "Victoria",
                "SCR", "Rupee", "+248", "SYC", "690", ".sc", 196 );

            CreateCountry( "SL", "Sierra Leone", "Republic of Sierra Leone", "Independent State", "", "", "Freetown",
                "SLL", "Leone", "+232", "SLE", "694", ".sl", 197 );

            CreateCountry( "SG", "Singapore", "Republic of Singapore", "Independent State", "", "", "Singapore", "SGD",
                "Dollar", "+65", "SGP", "702", ".sg", 198 );

            CreateCountry( "SK", "Slovakia", "Slovak Republic", "Independent State", "", "", "Bratislava", "SKK", "Koruna",
                "+421", "SVK", "703", ".sk", 199 );

            CreateCountry( "SI", "Slovenia", "Republic of Slovenia", "Independent State", "", "", "Ljubljana", "EUR",
                "Euro", "+386", "SVN", "705", ".si", 200 );

            CreateCountry( "SB", "Solomon Islands", "", "Independent State", "", "", "Honiara", "SBD", "Dollar",
                "+677", "SLB", "090", ".sb", 201 );

            CreateCountry( "SO", "Somalia", "", "Independent State", "", "", "Mogadishu", "SOS", "Shilling",
                "+252", "SOM", "706", ".so", 202 );

            CreateCountry( "ZA", "South Africa", "Republic of South Africa", "Independent State", "", "",
                "Pretoria (administrative), Cape Town (legislative), and Bloemfontein (judical)", "ZAR", "Rand", "+27",
                "ZAF", "710", ".za", 203 );

            CreateCountry( "GS", "South Georgia Island", "", "Dependency", "Overseas Territory", "United Kingdom",
                "", "", "", "", "SGS", "239", ".gs", 204 );

            CreateCountry( "ES", "Spain", "Kingdom of Spain", "Independent State", "", "", "Madrid", "EUR", "Euro",
                "+34", "ESP", "724", ".es", 205 );

            CreateCountry( "LK", "Sri Lanka", "Democratic Socialist Republic of Sri Lanka", "Independent State", "", "",
                "Colombo (administrative/judical) and Sri Jayewardenepura Kotte (legislative)", "LKR", "Rupee", "+94",
                "LKA", "144", ".lk", 206 );

            CreateCountry( "VC", "St. Vincent and the Grenadines", "", "Independent State", "", "", "Kingstown", "XCD",
                "Dollar", "+1-784", "VCT", "670", ".vc", 207 );

            CreateCountry( "SD", "Sudan", "Republic of the Sudan", "Independent State", "", "", "Khartoum", "SDD", "Dinar",
                "+249", "SDN", "736", ".sd", 208 );

            CreateCountry( "SR", "Suriname", "Republic of Suriname", "Independent State", "", "", "Paramaribo", "SRD",
                "Dollar", "+597", "SUR", "740", ".sr", 209 );

            CreateCountry( "SJ", "Svalbard", "", "Proto Dependency", "", "Norway", "Longyearbyen", "NOK", "Krone",
                "+47", "SJM", "744", ".sj", 210 );

            CreateCountry( "SZ", "Swaziland", "Kingdom of Swaziland", "Independent State", "", "",
                "Mbabane (administrative) and Lobamba (legislative)", "SZL", "Lilangeni", "+268", "SWZ", "748", ".sz", 211 );

            CreateCountry( "SE", "Sweden", "Kingdom of Sweden", "Independent State", "", "", "Stockholm", "SEK",
                "Kronoa", "+46", "SWE", "752", ".se", 212 );

            CreateCountry( "CH", "Switzerland", "Swiss Confederation", "Independent State", "", "", "Bern", "CHF",
                "Franc", "+41", "CHE", "756", ".ch", 213 );

            CreateCountry( "SY", "Syria", "Syrian Arab Republic", "Independent State", "", "", "Damascus", "SYP",
                "Pound", "+963", "SYR", "760", ".sy", 214 );

            CreateCountry( "TJ", "Tajikistan", "Republic of Tajikistan", "Independent State", "", "", "Dushanbe",
                "TJS", "Somoni", "+992", "TJK", "762", ".tj", 215 );

            CreateCountry( "TZ", "Tanzania", "United Republic of Tanzania", "Independent State", "", "",
                "Dar es Salaam (administrative/judical) and Dodoma (legislative)", "TZS", "Shilling",
                "+255", "TZA", "834", ".tz", 216 );

            CreateCountry( "TH", "Thailand", "Kingdom of Thailand", "Independent State", "", "", "Bangkok",
                "THB", "Baht", "+66", "THA", "764", ".th", 217 );

            CreateCountry( "TL", "Timor-Leste (East Timor)", "Democratic Republic of Timor-Leste", "Independent State",
                "", "", "Dili", "USD", "Dollar", "+670", "TLS", "626", ".tp and .tl", 218 );

            CreateCountry( "TG", "Togo", "Togolese Republic", "Independent State", "", "", "Lome", "XOF", "Franc",
                "+228", "TGO", "768", ".tg", 219 );

            CreateCountry( "TK", "Tokelau", "", "Dependency", "Territory", "New Zealand", "", "NZD", "Dollar",
                "+690", "TKL", "772", ".tk", 220 );

            CreateCountry( "TO", "Tonga", "Kingdom of Tonga", "Independent State", "", "", "Nuku'alofa", "TOP",
                "Pa'anga", "+676", "TON", "776", ".to", 221 );

            CreateCountry( "TT", "Trinidad and Tobago", "Republic of Trinidad and Tobago", "Independent State", "",
                "", "Port-of-Spain", "TTD", "Dollar", "+1-868", "TTO", "780", ".tt", 222 );

            CreateCountry( "TA", "Tristan da Cunha", "", "Proto Dependency", "Dependency of Saint Helena",
                "United Kingdom", "Edinburgh", "SHP", "Pound", "+290", "TAA", "", "", 223 );

            CreateCountry( "TN", "Tunisia", "Tunisian Republic", "Independent State", "", "", "Tunis", "TND",
                "Dinar", "+216", "TUN", "788", ".tn", 224 );

            CreateCountry( "TR", "Turkey", "Republic of Turkey", "Independent State", "", "", "Ankara", "TRY",
                "Lira", "+90", "TUR", "792", ".tr", 225 );

            CreateCountry( "TM", "Turkmenistan", "", "Independent State", "", "", "Ashgabat", "TMM", "Manat",
                "+993", "TKM", "795", ".tm", 226 );

            CreateCountry( "TC", "Turks and Caicos Islands", "", "Dependency", "Overseas Territory", "United Kingdom",
                "Grand Turk", "USD", "Dollar", "+1-649", "TCA", "796", ".tc", 227 );

            CreateCountry( "TV", "Tuvalu", "", "Independent State", "", "", "Funafuti", "AUD", "Dollar", "+688",
                "TUV", "798", ".tv", 228 );

            CreateCountry( "VI", "U.S. Virgin Islands", "United States Virgin Islands", "Dependency", "Territory",
                "United States", "Charlotte Amalie", "USD", "Dollar", "+1-340", "VIR", "850", ".vi", 229 );

            CreateCountry( "UG", "Uganda", "Republic of Uganda", "Independent State", "", "", "Kampala", "UGX",
                "Shilling", "+256", "UGA", "800", ".ug", 230 );

            CreateCountry( "UA", "Ukraine", "", "Independent State", "", "", "Kiev", "UAH", "Hryvnia", "+380",
                "UKR", "804", ".ua", 231 );

            CreateCountry( "AE", "United Arab Emirates", "United Arab Emirates", "Independent State", "", "",
                "Abu Dhabi", "AED", "Dirham", "+971", "ARE", "784", ".ae", 232 );

            CreateCountry( "GB", "United Kingdom", "United Kingdom of Great Britain and Northern Ireland",
                "Independent State", "", "", "London", "GBP", "Pound", "+44", "GBR", "826", ".uk", 233 );

            CreateCountry( "US", "United States", "United States of America", "Independent State", "", "",
                "Washington", "USD", "Dollar", "+1", "USA", "840", ".us", 234 );

            CreateCountry( "UY", "Uruguay", "Oriental Republic of Uruguay", "Independent State", "", "",
                "Montevideo", "UYU", "Peso", "+598", "URY", "858", ".uy", 235 );

            CreateCountry( "UZ", "Uzbekistan", "Republic of Uzbekistan", "Independent State", "", "", "Tashkent",
                "UZS", "Som", "+998", "UZB", "860", ".uz", 236 );

            CreateCountry( "VU", "Vanuatu", "Republic of Vanuatu", "Independent State", "", "", "Port-Vila",
                "VUV", "Vatu", "+678", "VUT", "548", ".vu", 237 );

            CreateCountry( "VA", "Vatican City", "State of the Vatican City", "Independent State", "", "",
                "Vatican City", "EUR", "Euro", "+379", "VAT", "336", ".va", 238 );

            CreateCountry( "VE", "Venezuela", "Bolivarian Republic of Venezuela", "Independent State", "", "",
                "Caracas", "VEB", "Bolivar", "+58", "VEN", "862", ".ve", 239 );

            CreateCountry( "VN", "Vietnam", "Socialist Republic of Vietnam", "Independent State", "", "", "Hanoi",
                "VND", "Dong", "+84", "VNM", "704", ".vn", 240 );

            CreateCountry( "WF", "Wallis and Futuna", "Collectivity of the Wallis and Futuna Islands", "Dependency",
                "Overseas Collectivity", "France", "Mata'utu", "XPF", "Franc", "+681", "WLF", "876", ".wf", 241 );

            CreateCountry( "EH", "Western Sahara", "", "Disputed Territory", "", "Administrated by Morocco", "El-Aaiun",
                "MAD", "Dirham", "+212", "ESH", "732", ".eh", 242 );

            CreateCountry( "YE", "Yemen", "Republic of Yemen", "Independent State", "", "", "Sanaa", "YER", "Rial",
                "+967", "YEM", "887", ".ye", 243 );

            CreateCountry( "ZM", "Zambia", "Republic of Zambia", "Independent State", "", "", "Lusaka", "ZMK", "Kwacha",
                "+260", "ZMB", "894", ".zm", 244 );

            CreateCountry( "ZW", "Zimbabwe", "Republic of Zimbabwe", "Independent State", "", "", "Harare", "ZWD",
                "Dollar", "+263", "ZWE", "716", ".zw", 245 );

        }

        public static void RestoreDefaultStateCode()
        {
            DataAccessContext.StateRepository.DeleteByCountry( "US" );
            CreateState( "US", "AL", "Alabama", 1 );
            CreateState( "US", "AK", "Alaska", 2 );
            CreateState( "US", "AZ", "Arizona", 3 );
            CreateState( "US", "AR", "Arkansas", 4 );
            CreateState( "US", "CA", "California", 5 );
            CreateState( "US", "CO", "Colorado", 6 );
            CreateState( "US", "CT", "Connecticut", 7 );
            CreateState( "US", "DE", "Delaware", 8 );
            CreateState( "US", "DC", "District Of Columbia", 9 );
            CreateState( "US", "FL", "Florida", 10 );
            CreateState( "US", "GA", "Georgia", 11 );
            CreateState( "US", "HI", "Hawaii", 12 );
            CreateState( "US", "ID", "Idaho", 13 );
            CreateState( "US", "IL", "Illinois", 14 );
            CreateState( "US", "IN", "Indiana", 15 );
            CreateState( "US", "IA", "Iowa", 16 );
            CreateState( "US", "KS", "Kansas", 17 );
            CreateState( "US", "KY", "Kentucky", 18 );
            CreateState( "US", "LA", "Louisiana", 19 );
            CreateState( "US", "ME", "Maine", 20 );
            CreateState( "US", "MD", "Maryland", 21 );
            CreateState( "US", "MA", "Massachusetts", 22 );
            CreateState( "US", "MI", "Michigan", 23 );
            CreateState( "US", "MN", "Minnesota", 24 );
            CreateState( "US", "MS", "Mississippi", 25 );
            CreateState( "US", "MO", "Missouri", 26 );
            CreateState( "US", "MT", "Montana", 27 );
            CreateState( "US", "NE", "Nebraska", 28 );
            CreateState( "US", "NV", "Nevada", 29 );
            CreateState( "US", "NH", "New Hampshire", 30 );
            CreateState( "US", "NJ", "New Jersey", 31 );
            CreateState( "US", "NM", "New Mexico", 32 );
            CreateState( "US", "NY", "New York", 33 );
            CreateState( "US", "NC", "North Carolina", 34 );
            CreateState( "US", "ND", "North Dakota", 35 );
            CreateState( "US", "OH", "Ohio", 36 );
            CreateState( "US", "OK", "Oklahoma", 37 );
            CreateState( "US", "OR", "Oregon", 38 );
            CreateState( "US", "PA", "Pennsylvania", 39 );
            CreateState( "US", "RI", "Rhode Island", 40 );
            CreateState( "US", "SC", "South Carolina", 41 );
            CreateState( "US", "SD", "South Dakota", 42 );
            CreateState( "US", "TN", "Tennessee", 43 );
            CreateState( "US", "TX", "Texas", 44 );
            CreateState( "US", "UT", "Utah", 45 );
            CreateState( "US", "VT", "Vermont", 46 );
            CreateState( "US", "VA", "Virginia", 47 );
            CreateState( "US", "WA", "Washington", 48 );
            CreateState( "US", "WV", "West Virginia", 49 );
            CreateState( "US", "WI", "Wisconsin", 50 );
            CreateState( "US", "WY", "Wyoming", 51 );

        }

    }
}
